require "dotenv/init/comment_aware_parser"

module Dotenv
  module Init
    class Assigner
      attr_reader :string, :env, :lines

      class << self
        def call(string, env)
          new(string, env).call
        end
      end

      def initialize(string, env)
        @string = string
        @lines = string.split(/[\n\r]/)
        @env = env
      end

      def call
        parsed.each do |key, value|
          line_number, offset, default = value.values_at(:line_number, :offset, :default)

          replacement = lines[line_number]
          replacement[range(offset)] = env[key] || default

          lines[line_number] = replacement
        end

        lines.join("\n") + "\n"
      end

      private

      def range(offset)
        offset[0]..(offset[1] - 1)
      end

      def parsed
        @parsed ||= CommentAwareParser.call(@string)
      end
    end
  end
end
