require "pry"

module Dotenv
  module Init
    class CLI
      class << self
        def start
          @file = File.open(".env.example")
          @contents = @file.read

          env = {}

          parsed.each do |key, value|
            print prompt(key, value)

            value = $stdin.gets.chomp
            env[key] = value.empty? ? nil : value
            puts
          end

          File.write(".env", Assigner.call(@contents, env))
        end

        def prompt(key, value)
          <<~PROMPT.chomp
            #{value[:comments]}
            #{try_color(key, :yellow)}: #{default_value(value)}
          PROMPT
        end

        def parsed
          @parsed ||= CommentAwareParser.call(@contents)
        end

        def default_value(value)
          try_color("(#{value[:default]}) ", :green) unless value[:default].empty?
        end

        def try_color(string, color)
          require "colorize"
          string.colorize(color)
        rescue LoadError
          string
        end
      end
    end
  end
end
